==> nextcloud-25.0.8.tgz: nextcloud/apps/serverinfo/l10n/eo.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informo pri la ĉefprocesoro ne disponeblas",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
    "System" : "Sistemo",
    "Monitoring" : "Observado",
    "Monitoring app with useful server information" : "Observa aplikaĵo kun utilaj informoj pri la servilo",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Montras utilajn servilajn informojn, kiel ŝarĝon de la ĉefprocesoro, ĉefmemoran uzadon, diskan uzadon, nombrojn de uzantoj, k.t.p.",
    "Temperature" : "Temperaturo",
    "Load" : "Ŝarĝo",
    "Memory" : "Ĉefmemoro",
    "Disk" : "Disko",
    "Size:" : "Grando:",
    "You will get a notification once one of your disks is nearly full." : "Ni sciigos vin, kiam disko preskaŭ plenos.",
    "Files:" : "Dosieroj:",
    "Storages:" : "Konservejoj:",
    "Free Space:" : "Libera spaco:",
    "Network" : "Reto",
    "Active users" : "Aktivaj uzantoj",
    "Total users:" : "Sumo de uzantoj:",
    "Shares" : "Kunhavoj",
    "Users:" : "Uzantoj:",
    "PHP" : "PHP",
    "Version:" : "Versio:",
    "Upload max size:" : "Maksimuma alŝutgrando:",
    "Database" : "Datumbazo",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ekstera observa ilo",
    "You can connect an external monitoring tool by using this end point:" : "Vi povas konekti eksteran observan ilon per tiu adreso:",
    "Copy" : "Kopii"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.9.tgz: nextcloud/apps/serverinfo/l10n/eo.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informo pri la ĉefprocesoro ne disponeblas",
    "Copied!" : "Kopiita!",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
    "System" : "Sistemo",
    "Monitoring" : "Observado",
    "Monitoring app with useful server information" : "Observa aplikaĵo kun utilaj informoj pri la servilo",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Montras utilajn servilajn informojn, kiel ŝarĝon de la ĉefprocesoro, ĉefmemoran uzadon, diskan uzadon, nombrojn de uzantoj, k.t.p.",
    "Temperature" : "Temperaturo",
    "Load" : "Ŝarĝo",
    "Memory" : "Ĉefmemoro",
    "Disk" : "Disko",
    "Size:" : "Grando:",
    "Files:" : "Dosieroj:",
    "Storages:" : "Konservejoj:",
    "Free Space:" : "Libera spaco:",
    "Network" : "Reto",
    "Active users" : "Aktivaj uzantoj",
    "Total users:" : "Sumo de uzantoj:",
    "Shares" : "Kunhavoj",
    "Users:" : "Uzantoj:",
    "PHP" : "PHP",
    "Version:" : "Versio:",
    "Upload max size:" : "Maksimuma alŝutgrando:",
    "Database" : "Datumbazo",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ekstera observa ilo",
    "Copy" : "Kopii",
    "You will get a notification once one of your disks is nearly full." : "Ni sciigos vin, kiam disko preskaŭ plenos.",
    "You can connect an external monitoring tool by using this end point:" : "Vi povas konekti eksteran observan ilon per tiu adreso:"
},
"nplurals=2; plural=(n != 1);");
